@@ -14,13 +14,21 @@ class Configure(object):
     last_config_modified = 0
     observers = []
     POD_NAME = os.environ.get("POD_NAME") if os.environ.get('POD_NAME') else os.environ.get("PODNAME") if os.environ.get("PODNAME") else ''
+    license = None
 
     @classmethod
     def init(cls, display=True):
-        
+        cls.loadFromEnv()
         cls.last_loaded = time.time()
         return cls.load(display)
 
+    @classmethod
+    def loadFromEnv(cls):
+        for key, value in Configuration.items():
+            setattr(cls, key, value)
+        if not hasattr(cls, "license") and hasattr(cls, "accesskey"):
+            setattr(cls, "license", getattr(cls, "accesskey"))
+
     @classmethod
     def load(cls, display=True):
         home = 'WHATAP_HOME'
@@ -29,8 +37,9 @@ class Configure(object):
             last_modified = os.path.getmtime(whatap_config)
             if cls.last_config_modified >= last_modified:
                 return True
-            for key, value in Configuration.items():
+            for key, value in os.environ.items():
                 setattr(cls, key, value)
+            
             with open(whatap_config, 'r') as f:
                 for line in f:
                     cls.last_config_modified = last_modified
@@ -48,6 +57,8 @@ class Configure(object):
                     except Exception as e:
                         print('WHATAP: ', e)
                         continue
+            if not getattr(cls, "license") and getattr(cls, "accesskey"):
+                setattr(cls, "license", getattr(cls, "accesskey"))
             for callback in cls.observers:
                 callback()
         except Exception as e:
@@ -65,6 +76,8 @@ class Configure(object):
     def getProperty(cls, key, value=None):
         if hasattr(cls, key):
             return getattr(cls, key)
+        elif key in os.environ:
+            return os.environ[key]
         else:
             return value
     
