@@ -13,7 +13,7 @@ from whatap.conf.configure import Configure as conf
 def load_module(module, fullname):
     # if conf.dev:
     #     logging.debug(fullname)
-
+            
     try:
         if fullname in IMPORT_HOOKS:
             wfullname = IMPORT_HOOKS[fullname]['module']
@@ -27,7 +27,10 @@ def load_module(module, fullname):
                 
             getattr(wmodule,
                     IMPORT_HOOKS[fullname]['def'])(module)
-
+            logging.info("successfully injected %s as %s", fullname, wfullname)
+        else:
+            if conf.debug:
+                logging.info("non-injected module %s ", fullname)
     except Exception as e:
         logging.debug(e, exc_info=True)
     finally:
@@ -54,6 +57,8 @@ class ImportFinder(object):
         if fullname not in IMPORT_HOOKS \
                 or fullname.startswith('whatap') \
                 or fullname.startswith('pip'):
+            if conf.debug:
+                logging.info("non-injected module %s ", fullname)
             return None
 
         if fullname in self._hooks:
@@ -74,4 +79,6 @@ class ImportFinder(object):
                 return _ImportHookLoader()
         
         except Exception as e:
+            if conf.dev:
+                print(e)
             return
